==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/files_external/l10n/ja.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "リクエストトークンの取得に失敗しました。アプリのキーとパスワードが正しいことを確認してください。",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "アクセストークンの取得に失敗しました。アプリのキーとパスワードが正しいことを確認してください。",
    "Please provide a valid app key and secret." : "有効なアプリのキーとパスワードを入力してください。",
    "Step 1 failed. Exception: %s" : "ステップ 1 の実行に失敗しました。例外: %s",
    "Step 2 failed. Exception: %s" : "ステップ 2 の実行に失敗しました。例外: %s",
    "External storage" : "外部ストレージ",
    "Dropbox App Configuration" : "Dropbox アプリ設定",
    "Google Drive App Configuration" : "Google アプリ設定",
    "Personal" : "個人",
    "System" : "システム",
    "Grant access" : "アクセスを許可",
    "Error configuring OAuth1" : "OAuth1 設定エラー",
    "Error configuring OAuth2" : "OAuth2 設定エラー",
    "Generate keys" : "キーを生成",
    "Error generating key pair" : "キーペアの生成エラー",
    "All users. Type to select user or group." : "すべてのユーザー。ユーザー、グループを追加",
    "(group)" : "(グループ)",
    "Compatibility with Mac NFD encoding (slow)" : "Mac NFD エンコード互換 (遅い)",
    "Admin defined" : "管理者設定済",
    "Saved" : "保存されました",
    "Saving..." : "保存中...",
    "Save" : "保存",
    "Empty response from the server" : "サーバーから空の応答がありました",
    "Couldn't access. Please logout and login to activate this mount point" : "アクセス出来ませんでした｡このマウントポイントを有効にするには一度ログアウトしてからログインしてください。",
    "Couldn't get the information from the remote server: {code} {type}" : "リモートサーバーから情報を取得できませんでした：{code} {type}",
    "Couldn't get the list of external mount points: {type}" : "外部マウントポイントのリストを取得出来ませんでした。: {type}",
    "There was an error with message: " : "メッセージ付きのエラーが発生しました：",
    "External mount error" : "外部マウントエラー",
    "external-storage" : "外部ストレージ",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Windows ネットワークドライブのマウントポイントリストを取得出来ませんでした:サーバーから空の応答がありました",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "いくつかの設定済み外部マウントポイントに接続できませんでした。詳細情報は赤い行をクリックしてください",
    "Please enter the credentials for the {mount} mount" : " {mount} のマウントのために必要な資格情報を入力してください",
    "Username" : "ユーザー名",
    "Password" : "パスワード",
    "Credentials saved" : "資格情報を保存しました",
    "Credentials saving failed" : "資格情報の保存に失敗しました",
    "Credentials required" : "資格情報が必要です",
    "Storage with id \"%i\" not found" : "ストレージID \"%i\" が見つかりません",
    "Invalid backend or authentication mechanism class" : "バックエンドまたは認証システムクラスが無効",
    "Invalid mount point" : "無効なマウントポイント",
    "Objectstore forbidden" : "オブジェクトストアが禁じられています",
    "Invalid storage backend \"%s\"" : "\"%s\" のストレージバックエンドが不正",
    "Not permitted to use backend \"%s\"" : "バックエンド %s を使うための権限がありません",
    "Not permitted to use authentication mechanism \"%s\"" : "認証システム %s を使う権限がありません",
    "Unsatisfied backend parameters" : "バックエンドのためのパラメーターが不十分です。",
    "Unsatisfied authentication mechanism parameters" : "認証のためのパラメータが不十分です",
    "Insufficient data: %s" : "データが不足しています: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "ストレージID \"%i\" はユーザーが編集できません",
    "Access key" : "アクセスキー",
    "Secret key" : "シークレットキー",
    "Builtin" : "ビルトイン",
    "None" : "なし",
    "OAuth1" : "OAuth1",
    "App key" : "アプリキー",
    "App secret" : "アプリシークレット",
    "OAuth2" : "OAuth2",
    "Client ID" : "クライアントID",
    "Client secret" : "クライアント秘密キー",
    "OpenStack" : "OpenStack",
    "Tenant name" : "テナント名",
    "Identity endpoint URL" : "認証エンドポイントURL",
    "Rackspace" : "Rackspace",
    "API key" : "APIキー",
    "Global credentials" : "グローバル資格情報",
    "Log-in credentials, save in database" : "ログイン認証情報は、データベースに保存されます。",
    "Username and password" : "ユーザー名とパスワード",
    "Log-in credentials, save in session" : "ログイン認証情報は、セッションに保存されます。",
    "User entered, store in database" : "入力されたユーザーデータは、データベースに保管します",
    "RSA public key" : "RSA公開鍵",
    "Public key" : "公開鍵",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "バケット名",
    "Hostname" : "ホスト名",
    "Port" : "ポート",
    "Region" : "リージョン",
    "Enable SSL" : "SSLを有効",
    "Enable Path Style" : "パス形式を有効",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "リモートサブフォルダー",
    "Secure https://" : "セキュア https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "ホスト",
    "Secure ftps://" : "Secure ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "ローカル",
    "Location" : "場所",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "ルート",
    "SFTP with secret key login" : "秘密鍵でSFTPログイン",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "共有",
    "Domain" : "ドメイン",
    "SMB / CIFS using OC login" : "ownCloudログインを利用したSMB / CIFS",
    "Username as share" : "共有名",
    "OpenStack Object Storage" : "OpenStack ObjectStorage",
    "Service name" : "サービス名",
    "Request timeout (seconds)" : "リクエストがタイムアウトするまでの秒数",
    "External storages" : "外部ストレージ",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHPでのcURLのサポートが有効になっていないか、インストールされていません。 %s のマウントは不可能です。システム管理者にインストールを依頼してください。",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHPのFTPサポートが有効になっていないか、インストールされていません。%s のマウントは不可能です。システム管理者にインストールを依頼してください。",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\"はインストールされていません。 %s のマウントは不可能です。システム管理者にインストールを依頼してください。",
    "No external storage configured" : "外部ストレージは設定されていません",
    "You can add external storages in the personal settings" : "個人設定で外部ストレージを設定することができます。",
    "Name" : "名前",
    "Storage type" : "ストレージ種別",
    "Scope" : "スコープ",
    "Enable encryption" : "暗号化を有効に",
    "Enable previews" : "プレビューを有効に",
    "Enable sharing" : "共有の有効化",
    "Check for changes" : "変更点を確認",
    "Never" : "更新無",
    "Once every direct access" : "直指定時のみ",
    "Folder name" : "フォルダー名",
    "Authentication" : "認証",
    "Configuration" : "設定",
    "Available for" : "利用可能",
    "Add storage" : "ストレージを追加",
    "Advanced settings" : "詳細設定",
    "Delete" : "削除",
    "Allow users to mount external storage" : "ユーザーに外部ストレージの接続を許可する",
    "Allow users to mount the following external storage" : "ユーザーに以下の外部ストレージのマウントを許可する",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "ownCloud サーバーから情報を取得出来ませんでした。: {code} {type}",
    "Access granted" : "アクセス権の付与",
    "Global Credentials" : "グローバル認証情報",
    "ownCloud" : "ownCloud",
    "<b>Note:</b> " : "<b>注意:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>注意:</b> PHPにcURLのエクステンションが入っていないか、有効ではありません。%s をマウントすることができません。このシステムの管理者にインストールをお願いしてください。",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>注意:</b> PHPにFTPのエクステンションが入っていないか、有効ではありません。%s をマウントすることができません。このシステムの管理者にインストールをお願いしてください。",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>注意:</b> \"%s\" がインストールされていません。%sをマウントできません。このシステムの管理者にインストールをお願いしてください。",
    "External Storage" : "外部ストレージ"
},
"nplurals=1; plural=0;");

==> nextcloud-12.0.7.tar.bz2: nextcloud/apps/files_external/l10n/ja.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "外部ストレージ",
    "Personal" : "個人",
    "System" : "システム",
    "Grant access" : "アクセスを許可",
    "Error configuring OAuth1" : "OAuth1 設定エラー",
    "Please provide a valid app key and secret." : "有効なアプリのキーとパスワードを入力してください。",
    "Error configuring OAuth2" : "OAuth2 設定エラー",
    "Generate keys" : "キーを生成",
    "Error generating key pair" : "キーペアの生成エラー",
    "All users. Type to select user or group." : "すべてのユーザー。ユーザー、グループを追加",
    "(group)" : "(グループ)",
    "Compatibility with Mac NFD encoding (slow)" : "Mac NFD エンコード互換 (遅い)",
    "Admin defined" : "管理者設定済",
    "Delete storage?" : "ストレージを削除しますか?",
    "Saved" : "保存されました",
    "Saving..." : "保存中...",
    "Save" : "保存",
    "Empty response from the server" : "サーバーから空の応答がありました",
    "Couldn't access. Please log out and in again to activate this mount point" : "アクセスできません。ログアウトして、再度このマウントポイントをアクティベートしてください。",
    "Couldn't get the information from the remote server: {code} {type}" : "リモートサーバーから情報を取得できませんでした：{code} {type}",
    "Couldn't get the list of external mount points: {type}" : "外部マウントポイントのリストを取得出来ませんでした。: {type}",
    "There was an error with message: " : "メッセージ付きのエラーが発生しました：",
    "External mount error" : "外部マウントエラー",
    "external-storage" : "外部ストレージ",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Windowsネットワークドライブのマウントポイントのリストが取得できませんでした: サーバーからのレスポンスは空でした。",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "いくつかの設定済み外部マウントポイントに接続できませんでした。詳細情報は赤い行をクリックしてください",
    "Please enter the credentials for the {mount} mount" : " {mount} のマウントのために必要な資格情報を入力してください",
    "Username" : "ユーザー名",
    "Password" : "パスワード",
    "Credentials saved" : "資格情報を保存しました",
    "Credentials saving failed" : "資格情報の保存に失敗しました",
    "Credentials required" : "資格情報が必要です",
    "Storage with ID \"%d\" not found" : "ID \"%d\" のストレージが見つかりません",
    "Invalid backend or authentication mechanism class" : "バックエンドまたは認証システムクラスが無効",
    "Invalid mount point" : "無効なマウントポイント",
    "Objectstore forbidden" : "オブジェクトストアが禁じられています",
    "Invalid storage backend \"%s\"" : "\"%s\" のストレージバックエンドが不正",
    "Not permitted to use backend \"%s\"" : "バックエンド %s を使うための権限がありません",
    "Not permitted to use authentication mechanism \"%s\"" : "認証システム %s を使う権限がありません",
    "Unsatisfied backend parameters" : "バックエンドのためのパラメーターが不十分です。",
    "Unsatisfied authentication mechanism parameters" : "認証のためのパラメータが不十分です",
    "Insufficient data: %s" : "データが不足しています: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "ID \"%d\" のストレージはユーザーが編集できません",
    "Access key" : "アクセスキー",
    "Secret key" : "シークレットキー",
    "Builtin" : "ビルトイン",
    "None" : "なし",
    "OAuth1" : "OAuth1",
    "App key" : "アプリキー",
    "App secret" : "アプリシークレット",
    "OAuth2" : "OAuth2",
    "Client ID" : "クライアントID",
    "Client secret" : "クライアント秘密キー",
    "Tenant name" : "テナント名",
    "Identity endpoint URL" : "認証エンドポイントURL",
    "Domain" : "ドメイン",
    "Rackspace" : "Rackspace",
    "API key" : "APIキー",
    "Global credentials" : "グローバル資格情報",
    "Log-in credentials, save in database" : "ログイン認証情報は、データベースに保存されます。",
    "Username and password" : "ユーザー名とパスワード",
    "Log-in credentials, save in session" : "ログイン認証情報は、セッションに保存されます。",
    "User entered, store in database" : "入力されたユーザーデータは、データベースに保管します",
    "RSA public key" : "RSA公開鍵",
    "Public key" : "公開鍵",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "バケット名",
    "Hostname" : "ホスト名",
    "Port" : "ポート",
    "Region" : "リージョン",
    "Enable SSL" : "SSLを有効",
    "Enable Path Style" : "パス形式を有効",
    "Legacy (v2) authentication" : "レガシー認証(v2)",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "リモートサブフォルダー",
    "Secure https://" : "セキュア https://",
    "FTP" : "FTP",
    "Host" : "ホスト",
    "Secure ftps://" : "Secure ftps://",
    "Local" : "ローカル",
    "Location" : "場所",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "ルート",
    "SFTP with secret key login" : "秘密鍵でSFTPログイン",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "共有",
    "SMB / CIFS using OC login" : "Nextcloud ログインを利用したSMB / CIFS",
    "Username as share" : "共有名",
    "OpenStack Object Storage" : "OpenStack ObjectStorage",
    "Service name" : "サービス名",
    "Request timeout (seconds)" : "リクエストがタイムアウトするまでの秒数",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHPでのcURLのサポートが有効になっていないか、インストールされていません。 %s のマウントは不可能です。システム管理者にインストールを依頼してください。",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "PHPのFTPサポートが有効になっていないか、インストールされていません。%s のマウントは不可能です。システム管理者にインストールを依頼してください。",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\"はインストールされていません。 %s のマウントは不可能です。システム管理者にインストールを依頼してください。",
    "External storage support" : "外部ストレージのサポート",
    "Name" : "名前",
    "Storage type" : "ストレージ種別",
    "Scope" : "スコープ",
    "Enable encryption" : "暗号化を有効に",
    "Enable previews" : "プレビューを有効に",
    "Enable sharing" : "共有の有効化",
    "Check for changes" : "変更点を確認",
    "Never" : "更新無",
    "Once every direct access" : "直指定時のみ",
    "Folder name" : "フォルダー名",
    "External storage" : "外部ストレージ",
    "Authentication" : "認証",
    "Configuration" : "設定",
    "Available for" : "利用可能",
    "Add storage" : "ストレージを追加",
    "Advanced settings" : "詳細設定",
    "Delete" : "削除",
    "Allow users to mount external storage" : "ユーザーに外部ストレージの接続を許可する",
    "Allow users to mount the following external storage" : "ユーザーに以下の外部ストレージのマウントを許可する",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "リクエストトークンの取得に失敗しました。アプリのキーとパスワードが正しいことを確認してください。",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "アクセストークンの取得に失敗しました。アプリのキーとパスワードが正しいことを確認してください。",
    "Step 1 failed. Exception: %s" : "ステップ 1 の実行に失敗しました。例外: %s",
    "Step 2 failed. Exception: %s" : "ステップ 2 の実行に失敗しました。例外: %s",
    "Dropbox App Configuration" : "Dropbox アプリ設定",
    "Google Drive App Configuration" : "Google アプリ設定",
    "OpenStack" : "OpenStack",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "No external storage configured" : "外部ストレージは設定されていません",
    "You can add external storages in the personal settings" : "個人設定で外部ストレージを設定することができます。",
    "Are you sure you want to delete this external storage" : "この外部ストレージを本当に削除しますか?"
},
"nplurals=1; plural=0;");
